@@ -1,8 +1,7 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 8 -*-
-//
+
 // clone.h: Rcpp R/C++ interface class library -- clone RObject's
 //
-// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2022 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -27,27 +26,31 @@
 namespace Rcpp{
 
 	template <typename UnaryOperator>
-	class StringTransformer : public std::unary_function<const char*, const char*>{
+#if __cplusplus < 201103L
+	    class StringTransformer : public std::unary_function<const char*, const char*> {
+#else
+        class StringTransformer : public std::function<const char*(const char*)> {
+#endif
 		public:
 		StringTransformer( const UnaryOperator& op_ ): op(op_), buffer(){}
 		~StringTransformer(){}
-		
+
 		const char* operator()(const char* input ) {
-			buffer = input ;
-			std::transform( buffer.begin(), buffer.end(), buffer.begin(), op ) ;
-			return buffer.c_str() ;
+			buffer = input;
+			std::transform( buffer.begin(), buffer.end(), buffer.begin(), op );
+			return buffer.c_str();
 		}
-		
-	private:	
-		const UnaryOperator& op ;
-		std::string buffer ;
-	} ;
-	
+
+	private:
+		const UnaryOperator& op;
+		std::string buffer;
+	};
+
 	template <typename UnaryOperator>
 	StringTransformer<UnaryOperator> make_string_transformer( const UnaryOperator& fun){
-		return StringTransformer<UnaryOperator>( fun ) ;
+		return StringTransformer<UnaryOperator>( fun );
 	}
-	
+
 }
 
 #endif
