@@ -15,30 +15,30 @@
 // WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//                                                       
+//
 // You should have received a copy of the GNU General Public License
 // along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef Rcpp_Module_generated_ctor_signature_h
 #define Rcpp_Module_generated_ctor_signature_h
 
-inline void ctor_signature( std::string& s, const std::string& classname ){
-    s.clear() ;
-    s+= "()" ; 
+inline void ctor_signature( std::string& s, const std::string& classname){
+    s.assign(classname) ;
+    s+= "()" ;
 }
 
 template <typename U0>
 inline void ctor_signature( std::string& s, const std::string& classname ){
-    s.clear() ;
-    s += "(" ; 
+    s.assign(classname) ;
+    s += "(" ;
     s += get_return_type<U0>() ;
     s += ")" ;
 }
 
 template <typename U0, typename U1>
 inline void ctor_signature( std::string& s, const std::string& classname ){
-    s.clear() ;
-    s += "(" ; 
+    s.assign(classname) ;
+    s += "(" ;
     s += get_return_type<U0>() ;
     s += ", " ; s+= get_return_type<U1>() ;
     s += ")" ;
@@ -46,8 +46,8 @@ inline void ctor_signature( std::string& s, const std::string& classname ){
 
 template <typename U0, typename U1, typename U2>
 inline void ctor_signature( std::string& s, const std::string& classname ){
-    s.clear() ;
-    s += "(" ; 
+    s.assign(classname) ;
+    s += "(" ;
     s += get_return_type<U0>() ;
     s += ", " ; s+= get_return_type<U1>() ;
     s += ", " ; s+= get_return_type<U2>() ;
@@ -56,8 +56,8 @@ inline void ctor_signature( std::string& s, const std::string& classname ){
 
 template <typename U0, typename U1, typename U2, typename U3>
 inline void ctor_signature( std::string& s, const std::string& classname ){
-    s.clear() ;
-    s += "(" ; 
+    s.assign(classname) ;
+    s += "(" ;
     s += get_return_type<U0>() ;
     s += ", " ; s+= get_return_type<U1>() ;
     s += ", " ; s+= get_return_type<U2>() ;
@@ -67,8 +67,8 @@ inline void ctor_signature( std::string& s, const std::string& classname ){
 
 template <typename U0, typename U1, typename U2, typename U3, typename U4>
 inline void ctor_signature( std::string& s, const std::string& classname ){
-    s.clear() ;
-    s += "(" ; 
+    s.assign(classname) ;
+    s += "(" ;
     s += get_return_type<U0>() ;
     s += ", " ; s+= get_return_type<U1>() ;
     s += ", " ; s+= get_return_type<U2>() ;
@@ -79,8 +79,8 @@ inline void ctor_signature( std::string& s, const std::string& classname ){
 
 template <typename U0, typename U1, typename U2, typename U3, typename U4, typename U5>
 inline void ctor_signature( std::string& s, const std::string& classname ){
-    s.clear() ;
-    s += "(" ; 
+    s.assign(classname) ;
+    s += "(" ;
     s += get_return_type<U0>() ;
     s += ", " ; s+= get_return_type<U1>() ;
     s += ", " ; s+= get_return_type<U2>() ;
@@ -92,8 +92,8 @@ inline void ctor_signature( std::string& s, const std::string& classname ){
 
 template <typename U0, typename U1, typename U2, typename U3, typename U4, typename U5, typename U6>
 inline void ctor_signature( std::string& s, const std::string& classname ){
-    s.clear() ;
-    s += "(" ; 
+    s.assign(classname) ;
+    s += "(" ;
     s += get_return_type<U0>() ;
     s += ", " ; s+= get_return_type<U1>() ;
     s += ", " ; s+= get_return_type<U2>() ;
